//
//  StartGameConfirmationViewController.swift
//
//  Created by Laura Sempere on 9/12/2017.
//  Copyright © 2017 laurasempere. All rights reserved.
//

import UIKit

class GameStatusDialogViewController: ModalViewController {
        
    override func viewDidLoad() {
        guard let confirmationDailog = self.modalView as? ConfirmationDialog else { return }
        guard let gameStatus = GameManager.instance.gameStatus else { return }

        switch gameStatus {
        case .start:
            confirmationDailog.titleLabel.text = GameManager.instance.placeType?.getTitle()
            confirmationDailog.subtitleLabel.text = "AR you ready?"
            confirmationDailog.confirmationButton.setTitle("YES!", for: .normal)
            if let placeTypeImage = GameManager.instance.placeType?.getImage() {
                confirmationDailog.iconImage.image = UIImage(named:placeTypeImage)
            }
            confirmationDailog.onConfimation = { [weak self] in
                self?.navigateToGameViewController()
            }
        case .farAway:
            confirmationDailog.titleLabel.text = GameManager.instance.placeType?.getTitle()
            if let placeTypeImage = GameManager.instance.placeType?.getImage() {
                confirmationDailog.iconImage.image = UIImage(named:placeTypeImage)
            }
            confirmationDailog.subtitleLabel.text = "You are too far from this place. Get closer to play"
            confirmationDailog.onConfimation = {[weak self] in
                self?.dismiss(animated: true, completion: nil)
            }
        case .dismiss:
            confirmationDailog.titleLabel.text = "Exit"
            confirmationDailog.subtitleLabel.text = "AR you sure you want to exit? \n Don't worry, we are saving your progress"
            confirmationDailog.onConfimation = {[weak self] in
                self?.dismiss(animated: true, completion: {[weak self] in
                    self?.dismissGameViewController()
                })
            }
        case .end:
            if GameManager.instance.placeType == .general {
                DataService.instance.updateExtraContent(available: false)
            }
            self.enableBackgroundTap = false
            confirmationDailog.iconImage.image = UIImage(named:"Success")
            confirmationDailog.titleLabel.text = "Congratulations!"
            confirmationDailog.subtitleLabel.text = "You learnt \(GameManager.instance.learntWords.count) new words"
            confirmationDailog.onConfimation = {[weak self] in
                self?.dismiss(animated: true, completion: {
                    self?.dismissGameViewController()
                })
            }
        case .review:
            if let locationName = GameManager.instance.placeType?.getTitle() {
                confirmationDailog.titleLabel.text = locationName
            }
            if let placeTypeImage = GameManager.instance.placeType?.getImage() {
                confirmationDailog.iconImage.image = UIImage(named:placeTypeImage)
            }
            confirmationDailog.subtitleLabel.text = "AR you ready?"
            confirmationDailog.confirmationButton.setTitle("YES!", for: .normal)
            confirmationDailog.onConfimation = { [weak self] in
                self?.navigateToGameViewController()
            }
        case .fail:
            confirmationDailog.iconImage.image = UIImage(named:"Wrong")
            confirmationDailog.titleLabel.text = "Something went wrong!"
            confirmationDailog.subtitleLabel.text = "There are no words to learn here"
            confirmationDailog.confirmationButton.setTitle("EXIT!", for: .normal)
            confirmationDailog.onConfimation = {[weak self] in
                NotificationCenter.default.post(name: .dissmissGame, object: nil)
                self?.dismiss(animated: true, completion: {[weak self] in
                    self?.dismissGameViewController()
                })
            }
            
        }
        super.viewDidLoad()
    }
    
    func navigateToGameViewController() {
        if let arGameVC = self.storyboard?.instantiateViewController(withIdentifier: "ARGameViewController") as? ARGameViewController {
            self.dismiss(animated: true, completion: {
                let topVC = getTopViewController()
                topVC.present(arGameVC, animated: true, completion: nil)
            })
        }
    }
    
    func dismissGameViewController() {
        if let topVC = getTopViewController() as? ARGameViewController {
            topVC.dismiss(animated: true, completion: nil)
        }
    }
    
}

