//
//  LearntWordsViewController.swift
//
//  Created by Laura Sempere on 11/12/2017.
//  Copyright © 2017 laurasempere. All rights reserved.
//

import UIKit

class LearntWordsViewController: UIViewController, UITableViewDelegate, UITableViewDataSource {

    let learntWordsCell = "LearntWordsCell"
    let startGameSegue = "StartGameConfirmationSegue"
    
    var words:[Word]?
    
    var wordsByLocation:[String: [Word]]? {
        return words?.group{$0.location!}
    }
    var locations:[String]? {
        return words?.group{$0.location!}.map{$0.0}
    }
    
    @IBOutlet weak var tableView: UITableView!
    
    override func viewDidLoad() {
        tableView.isHidden = true
        super.viewDidLoad()
        tableView.delegate = self
        tableView.dataSource = self
        tableView.rowHeight = UITableViewAutomaticDimension
        tableView.estimatedRowHeight = 100
        DataService.instance.getLearntWords {[weak self] (words, error) in
            guard let words = words else { return }
            self?.words = words
            self?.tableView.isHidden = false
            self?.tableView.reloadData()
        }
    }
    
    @IBAction func reviewAllButtonWasPressed(_ sender: Any) {
        performSegue(withIdentifier: startGameSegue, sender: "all")
    }
    func numberOfSections(in tableView: UITableView) -> Int {
        return locations?.count ?? 0
    }
    
    func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        guard (locations?[section]) != nil else {return 0}
        return 1
    }
    
    func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        guard let cell = tableView.dequeueReusableCell(withIdentifier: learntWordsCell) as? LearntWordsCell else {
            return UITableViewCell()
        }
        guard let location = locations?[indexPath.section], let words = wordsByLocation?[location] else { return cell }
        cell.onReview = {
            self.performSegue(withIdentifier: self.startGameSegue, sender: location)
            
        }
        
        cell.configureCell(words: words, location: location)
        
        return cell
    }
    
    func tableView(_ tableView: UITableView, viewForFooterInSection section: Int) -> UIView? {
        return UIView()
    }
}

// MARK: Navigation
extension LearntWordsViewController {
    override func prepare(for segue: UIStoryboardSegue, sender: Any?) {
        if let location =  sender as? String, let words = words, let locationType = stringToPlaceType(location) {
            var wordsToPlay:[Word] {
                if locationType == .all {
                    return words
                } else {
                    guard let wordsByLoc =  wordsByLocation?[location] else {
                        return []
                    }
                    return wordsByLoc
                }
            }
            
            GameManager.instance.createNewReviewGame(for: wordsToPlay, at: locationType)
            GameManager.instance.updateGameStatus(to: .review)
        }
    }
}
