//
//  UserProfileViewController.swift
//
//  Created by Laura Sempere on 11/12/2017.
//  Copyright © 2017 laurasempere. All rights reserved.
//

import UIKit

class UserProfileViewController: UIViewController, UITableViewDelegate, UITableViewDataSource, Alertable {

    let userHeaderCell = "UserHeaderCell"
    let userStatisticCell = "UserStatisticCell"
    
    @IBOutlet weak var bonusContentButton: RoundedButton!
    @IBOutlet weak var tableView: UITableView!
    override func viewDidLoad() {
        super.viewDidLoad()
        tableView.delegate = self
        tableView.dataSource = self
        tableView.rowHeight = UITableViewAutomaticDimension
        tableView.estimatedRowHeight = 60
    }
    
    override func viewWillAppear(_ animated: Bool) {
        super.viewWillAppear(animated)
        self.navigationController?.navigationBar.isHidden = false
        DataService.instance.getUserDetails(completion: { [weak self] in
            self?.tableView.reloadData()
            guard let extraContent = DataService.instance.userDetails?.extraContentAvailable, extraContent == true else {
                self?.bonusContentButton.isHidden = true
                return
            }
            self?.bonusContentButton.isHidden = false

        })
    }
    
    
    @IBAction func bonusContentButtonWasPressed(_ sender: Any) {
        GameManager.instance.createNewGame(for: "A1", at: .general)
        performSegue(withIdentifier: "StartGameConfirmationSegue", sender: nil)
    }
    
    @IBAction func logoutButtonWasPressed(_ sender: Any) {
        let logoutPopup = UIAlertController(title: "Logout?", message: "Are you sure you want to logout?", preferredStyle: .actionSheet)
        let logoutAction = UIAlertAction(title: "Logout?", style: .destructive) { (buttonTapped) in
            AuthService.instance.logoutUser(logoutComplete: { (logoutComplete) in
                if logoutComplete == true {
                    let loginVC = self.storyboard?.instantiateViewController(withIdentifier: "LoginViewController") as! LoginViewController
                    self.present(loginVC, animated: true, completion: nil)
                }
            })
        }
        
        let cancelAction = UIAlertAction(title: "Cancel", style: .cancel) { (cancelTapped) in
            self.dismiss(animated: true, completion: nil)
        }
        logoutPopup.addAction(logoutAction)
        logoutPopup.addAction(cancelAction)
        present(logoutPopup, animated: true, completion: nil)
    }
    
    
    // MARK: Table view delegate and data source methods
    func numberOfSections(in tableView: UITableView) -> Int {
        return 1
    }
    
    func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        return 3
    }

    func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        switch indexPath.row {
        case 0: return getuserHeaderCell()
        default: return getuserStatisticCell(for: indexPath)
        }
    }
    
    func getuserHeaderCell() -> UserHeaderCell {
        guard let cell =  tableView.dequeueReusableCell(withIdentifier: userHeaderCell) as? UserHeaderCell else {
            return UserHeaderCell()
        }
        cell.configureCell()
        cell.backgroundColor = Colors.white
        return cell
    }
    
    func getuserStatisticCell(for indexPath:IndexPath) -> UserStatisticCell {
        guard let cell =  tableView.dequeueReusableCell(withIdentifier: userStatisticCell) as? UserStatisticCell else {
            return UserStatisticCell()
        }
        
        guard let userDetails = DataService.instance.userDetails else { return cell }
        switch indexPath.row {
        case 1: cell.configureCell(imageName: "school", title: "\(userDetails.learntWords?.count ?? 0)", subtitle: "Words")
        case 2: cell.configureCell(imageName: "points", title: "\(userDetails.points)", subtitle: "Points")
        default: break
        }
        
        return cell
    }
    
    func tableView(_ tableView: UITableView, didSelectRowAt indexPath: IndexPath) {
        guard let userDetails = DataService.instance.userDetails else { return }
        if indexPath.row == 1 {
            if userDetails.learntWords != nil {
                performSegue(withIdentifier: "LearntWordsSegue", sender: nil)
            } else {
                showAlert("You don't have any words yet", "Check the map to see where you can learn new words")
            }
        }
    }
    
    func tableView(_ tableView: UITableView, heightForRowAt indexPath: IndexPath) -> CGFloat {
        switch indexPath.row {
        case 0: return 270
        default: return 100
        }
    }
    
    func tableView(_ tableView: UITableView, viewForFooterInSection section: Int) -> UIView? {
        return UIView()
    }
    
}
