//
//  GameManager.swift
//
//  Created by Laura Sempere on 9/12/2017.
//  Copyright © 2017 laurasempere. All rights reserved.
//

import Foundation
let ALL_GENERAL_CATEGORIES:[GeneralCategories] = [.bodyParts, .physicCharacteristics, .personality, .nationalities, .personalObjects, .proffesions]

class GameManager {
    
    // Singleton instance
    static let instance = GameManager()
    
    var placeType:PlaceTypes?
    var level:String?
    private(set) var gameStatus:GameStatus?
    private(set) var words:[Word]?
    
    
    private(set) var learntWords:Set<String> = []
    
    var isGameOver: Bool {
        if let words = words {
            return words.count == learntWords.count
        } else {
            return false
        }
    }
    
   @objc fileprivate func resetGame() {
        self.words = nil
        self.learntWords = []
        self.placeType = nil
        self.level = nil
        self.gameStatus = nil
    }
    
    func newWordLearnt(wordId: String) {
        learntWords.insert(wordId)
        DataService.instance.addLearntWord(wordId: wordId)
        if isGameOver {
            updateGameStatus(to: .end)
            NotificationCenter.default.post(name: .gameOver, object: nil)
        }
    }
    
    func updateGameStatus(to status: GameStatus) {
       gameStatus = status
    }
    
    fileprivate func getWordsToPlay(_ placeType: PlaceTypes, _ level: String, _ learntWordsIds: [String]?, completionStatus: @escaping CompletionStatus) {
        var placeTypeId:String?
        if placeType == .general {
            placeTypeId = ALL_GENERAL_CATEGORIES.randomElement.toIdString()
           
        } else {
            placeTypeId = placeType.toIdString()
        }
        
        if let placeTypeId = placeTypeId {
            DataService.instance.getGame(for: level, at: placeTypeId, completion: { (words, error) in
                guard let words = words else { return completionStatus(false) }
                
                var wordsToLearn:[Word] = []
                // If the user has already learnt words
                if let learntWordsIds = learntWordsIds {
                    // Filter the learnt words from the words retrieved from the db
                    let userLearntWords:[Word] = words.filter{learntWordsIds.contains($0.id)}
                    wordsToLearn =  words.filter{!learntWordsIds.contains($0.id)}
                    // If the filtered words count is less than 3, add 3 words from the learnt ones
                    if wordsToLearn.count < 3 && userLearntWords.count > 0 {
                        wordsToLearn.append(contentsOf: userLearntWords.safeSuffix(3))
                        // If the words to learn count is bigger than 6, return only the last 6 words
                    } else if wordsToLearn.count > 6 {
                        wordsToLearn = wordsToLearn.safeSuffix(6)
                    }
                    self.words = wordsToLearn
                } else {
                    // Return the last 6 words
                    self.words = words.safeSuffix(6)
                }
                   
                completionStatus(true)
                
            })
        }
    }
    
    func createNewGame(for level: String, at placeType: PlaceTypes) {
        self.gameStatus = .start
        NotificationCenter.default.addObserver(self, selector: #selector(resetGame), name: .gameDismissed, object: nil)
        self.level = level
        self.placeType = placeType
        self.learntWords = []
        DataService.instance.getUserDetails(completion: {
            var userLearntWordsIds: [String]? {
                if let learnt = DataService.instance.userDetails?.learntWords {
                    return learnt.map{$0.key}
                } else {
                    return nil
                }
            }
            self.getWordsToPlay(placeType, level, userLearntWordsIds, completionStatus: { (success) in
                if success {
                    NotificationCenter.default.post(name: .newGameCreated, object: nil)
                } else {
                    self.gameStatus = .fail
                    NotificationCenter.default.post(name: .failToCreateNewGame, object: nil)
                }
            })
        })
    }
    
    func createNewReviewGame(for words: [Word], at placeType: PlaceTypes) {
        NotificationCenter.default.addObserver(self, selector: #selector(resetGame), name: .gameDismissed, object: nil)
        self.words = words
        self.learntWords = []
        self.placeType = placeType
        self.gameStatus = .start
        NotificationCenter.default.post(name: .newGameCreated, object: nil)
    }
    
}
