//
//  PlaceTypes.swift
//
//  Created by Laura Sempere on 10/12/2017.
//  Copyright © 2017 laurasempere. All rights reserved.
//

import Foundation


enum PlaceTypes {
    
    case general, travel, food, animals, education, culture, entertainment, sport, house, health, publicServices, shopping, transportation, pointOfInterest, all, bodyParts, physicCharacteristics, personality, nationalities, personalObjects, proffesions
    
    enum General {
        case bodyParts, physicCharacteristics, personality, nationalities, personalObjects, proffesions
    }
    
    func toIdString() -> String? {
        switch self {
        case .travel: return "travel"
        case .culture: return "culture"
        case .entertainment: return "entertainment"
        case .education: return "education"
        case .food: return "food"
        case .transportation: return "transportation"
        case .sport: return "sport"
        case .shopping: return "shopping"
        case .animals: return "animals"
        case .health: return "health"
        case .pointOfInterest: return "point_of_interest"
        case .publicServices: return "public_services"
        case .general: return "general"
        case .house: return "house"
        case .all: return "all"
        case .bodyParts: return "body_parts"
        case .physicCharacteristics: return "physic_characteristics"
        case .personality: return "personality"
        case .nationalities: return "nationalities"
        case .personalObjects: return "personal_objects"
        case .proffesions: return "proffesions"
        }
    }
    
    func getTitle() -> String? {
        switch self {
        case .travel: return "Viajes"
        case .culture: return "Cultura"
        case .entertainment: return "Entretenimiento"
        case .education: return "Educación"
        case .food: return "Comida"
        case .transportation: return "Transporte"
        case .sport: return "Deporte"
        case .shopping: return "Compras"
        case .animals: return "Animales"
        case .health: return "Salud"
        case .pointOfInterest: return "Punto de Interés"
        case .publicServices: return "Servicios Públicos"
        case .general: return "Contenido Extra"
        case .house: return "Casa"
        case .all: return "Todo"
        case .bodyParts: return "Partes del cuerpo"
        case .nationalities: return "Nacionalidades"
        case .physicCharacteristics: return "Características Físicas"
        case .personality: return "Personalidad"
        case .personalObjects: return "Objetos Personales"
        case .proffesions: return "Profesiones"
        }
    }
    
    func getImage() -> String? {
        switch self {
        case .animals: return "Animales"
        case .culture: return "Cultura"
        case .education: return "Education"
        case .entertainment: return "Entretenimiento"
        case .food: return "Comida"
        case .health: return "Salud"
        case .house: return "Casa"
        case .pointOfInterest: return "PuntoDeInteres"
        case .shopping: return "Compras"
        case .transportation: return "Transporte"
        case .travel: return "Viaje"
        case .sport: return "Deporte"
        default: return nil
        }
    }
    
}

let discardedPlaceTypes = ["accounting", "bowling_alley", "establishment", "campground", "electrician", "florist", "funeral_home", "general_contractor", "lodging", "meal_delivery", "meal_takeaway", "moving_company", "painter", "place_of_worship", "plumber", "real_estate_agency", "roofing_contractor", "rv_park", "storage", "administrative_area_level_1", "administrative_area_level_2", "administrative_area_level_3", "administrative_area_level_4", "administrative_area_level_5", "colloquial_area", "country", "geocode", "intersection", "locality", "place_of_worship", "postal_code_prefix", "postal_code_suffix", "postal_town", "premise", "route", "sublocality", "sublocality_level_4", "sublocality_level_3", "home_goods_store", "sublocality_level_2", "sublocality_level_1", "subpremise", "gas_station", "furniture_store", "insurance_agency", "liquor_store", "local_government_office", "locksmith", "laundry", "funeral_home", "beauty_salon", "hair_care", "spa"]

 func stringToPlaceType(_ primaryPlaceType: String) -> PlaceTypes? {
    switch primaryPlaceType {
    case "airport": return PlaceTypes.travel
    case "amusement_park": return PlaceTypes.entertainment
    case "aquarium": return PlaceTypes.animals
    case "art_gallery", "museum", "theater": return PlaceTypes.culture
    case "movie_rental", "cinema", "movie_theater", "casino", "night_club": return PlaceTypes.entertainment
    case "bar", "cafe", "food", "restaurant", "bakery", "grocery_or_supermarket": return PlaceTypes.food
    case "book_store", "library": return PlaceTypes.education
    case "car_dealer", "car_rental", "car_repair", "car_wash", "bicycle_store", "parking": return PlaceTypes.transportation
    case "bus_station", "station", "subway_station", "train_station", "transit_station" : return PlaceTypes.transportation
    case "church", "hindu_temple", "mosque", "temple", "synagogue": return PlaceTypes.pointOfInterest
    case "clothing_store", "shoe_store": return PlaceTypes.shopping
    case "shopping_mall": return PlaceTypes.shopping
    case "convenience_store", "store", "department_store", "jewelry_store": return PlaceTypes.shopping
    case "doctor", "hospital", "pharmacy", "dentist", "physiotherapist", "health": return PlaceTypes.health
    case "fire_station", "police", "post_office", "courthouse", "city_hall", "embassy": return PlaceTypes.publicServices
    case "gym", "sport", "stadium": return PlaceTypes.sport
    case "pet_store", "veterinary_care", "zoo" : return PlaceTypes.animals
    case "school", "university": return PlaceTypes.education
    case "point_of_interest", "park", "cemetery": return PlaceTypes.pointOfInterest
    case "neighborhood", "street_number", "street_address", "postal_code", "floor", "room": return PlaceTypes.house
    case "body_parts": return PlaceTypes.bodyParts
    case "physic_characteristics": return PlaceTypes.physicCharacteristics
    case "personality": return PlaceTypes.personality
    case "nationalities" : return PlaceTypes.nationalities
    case "personal_objects": return PlaceTypes.personalObjects
    case "proffesions": return PlaceTypes.proffesions
    case "all" : return PlaceTypes.all
    default: return nil
    }
}


func getPrimaryPlaceType(placeTypes: [String]) -> PlaceTypes? {
    let primaryPlaceTypes = placeTypes.filter { placeType in
        return !discardedPlaceTypes.contains(placeType)
    }
    if let primaryPlaceType = primaryPlaceTypes.first {
        return stringToPlaceType(primaryPlaceType)
    }
    return nil
}
