//
//  CollectionExtension.swift
//
//  Created by Laura Sempere on 11/12/2017.
//  Copyright © 2017 laurasempere. All rights reserved.
//

import Foundation

extension Collection {
    
    func group<U : Hashable>(by key: (Iterator.Element) -> U) -> [U:[Iterator.Element]] {
        var dict: [U:[Iterator.Element]] = [:]
        for el in self {
            let key = key(el)
            if case nil = dict[key]?.append(el) { dict[key] = [el] }
        }
        return dict
    }

    
    
    func safeSuffix(_ maxLength: Self.IndexDistance) -> Array<Element> {
        guard let index = self.index(endIndex, offsetBy: -maxLength, limitedBy: startIndex) else {
            return Array(self[startIndex ..< endIndex])
        }
        return Array(self[index ..< endIndex])
    }
    
    func safePrefix(_ maxLength: Self.IndexDistance) -> Array<Element> {
        guard let index = self.index(startIndex, offsetBy: maxLength, limitedBy: endIndex) else {
            return Array(self[startIndex ..< endIndex])
        }
        return Array(self[startIndex ..< index])
    }
    
    func safeFromIndex(_ maxLength: Self.IndexDistance, startAt:Self.Index) -> Array<Element> {
        if startAt < endIndex {
            guard let finalIndex = self.index(startAt, offsetBy: maxLength, limitedBy: endIndex) else {
                return Array(self[startAt ..< endIndex])
            }
            
            return Array(self[startAt ..< finalIndex])
        } else {
            return Array(self[endIndex ..< endIndex])
        }
        
    }
}
