//
//  Alertable.swift
//
//  Created by Laura Sempere on 26/11/2017.
//  Copyright © 2017 laurasempere. All rights reserved.
//

import UIKit

protocol Alertable {}

extension Alertable where Self: UIViewController {
    func showAlert(_ title: String, _ msg: String) {
        let alertController = UIAlertController(title: title, message: msg, preferredStyle: .alert)
        let action = UIAlertAction(title: "OK", style: .default, handler: nil)
        alertController.addAction(action)
        present(alertController, animated: true, completion: nil)
    }
    
    func showModal(identifier: String) {
        if let modalVC = self.storyboard?.instantiateViewController(withIdentifier: identifier) as? ModalViewController {
            modalVC.providesPresentationContextTransitionStyle = true
            modalVC.definesPresentationContext = true
            modalVC.modalPresentationStyle = UIModalPresentationStyle.overCurrentContext
            modalVC.modalTransitionStyle = UIModalTransitionStyle.crossDissolve
            present(modalVC, animated: true, completion: nil)
        }
    }
    
    func showLoading() {
        let storyboard = UIStoryboard(name: "Main", bundle: Bundle.main)
        if let loadingVC = storyboard.instantiateViewController(withIdentifier: "LoadingViewController") as? LoadingViewController {
            loadingVC.providesPresentationContextTransitionStyle = true
            loadingVC.definesPresentationContext = true
            loadingVC.modalPresentationStyle = .overCurrentContext
            loadingVC.modalTransitionStyle = .crossDissolve
            present(loadingVC, animated: true, completion: nil)
        }
    }
    
    func hideLoading(hideCompletion: (() -> Void)?) {
        let topVC = getTopViewController()
        if let navigationController = topVC as? CustomNavigationController {
            navigationController.visibleViewController?.dismiss(animated: true, completion: hideCompletion)
        } else {
            if let topVC = topVC as? LoadingViewController {
                topVC.dismiss(animated: true, completion: hideCompletion)
            }
        }
    }
    
}
