//
//  GooglePlacesService.swift
//
//  Created by Laura Sempere on 26/11/2017.
//  Copyright © 2017 laurasempere. All rights reserved.
//

import Foundation
import Alamofire


struct GooglePlacesLocation: Codable {
    let lat:Double
    let lng:Double
}

struct GooglePlacesGeometry: Codable {
    let location:GooglePlacesLocation?
}

struct GooglePlaces: Codable {
    let geometry: GooglePlacesGeometry?
    let name:String?
    let types: [String]?
}

struct GooglePlacesResultsResponse: Codable {
    let nextPageToken:String?
    let results: [GooglePlaces]
    
    enum CodingKeys: String, CodingKey {
        case results
        case nextPageToken = "next_page_token"
    }
}

private let RADIUS = 2000

class GooglePlacesService {
    
    static let instance = GooglePlacesService()
    
    func getPlacesFor(longitude:Double, latitude: Double, completion: @escaping (_ places: [GooglePlaces]?, _ error: String?) -> Void) {
        let urlString = "\(Constants.GooglePlacesAPI)?location=\(latitude),\(longitude)&radius=\(RADIUS)&key=\(Constants.GooglePlacesAPIKey)"
        if let url = URL(string:urlString) {
            Alamofire.request(url).responseJSON(completionHandler: { (response) in
                guard response.error == nil else {
                    return
                }  
                guard let data = response.data else {
                    return
                }
                let decoder = JSONDecoder()
                do {
                    let decodedResp = try decoder.decode(GooglePlacesResultsResponse.self, from: data)
                    completion(decodedResp.results, nil)
                } catch {
                    completion(nil, error.localizedDescription)
                    print("Error decoding data: \(error)")
                }
            })
        }
    }
    
}
