//
//  UserInitials.swift
//
//  Created by Laura Sempere on 11/12/2017.
//  Copyright © 2017 laurasempere. All rights reserved.
//

import UIKit

class UserInitials: NibView {
    
    var onUserProfile:(()->Void)?
    
    @IBOutlet var buttonBackground: RoundedShadowView!
    @IBOutlet weak var initialsButton: UIButton!
    
    @IBAction func userButtonWasPressed(_ sender: Any) {
        onUserProfile?()
    }

    override func awakeFromNib() {
        super.awakeFromNib()
        self.layer.cornerRadius = self.layer.bounds.height / 2
        NotificationCenter.default.addObserver(self, selector: #selector(resetUserDetails), name: .logout, object: nil)
        initialsButton.tintColor = Colors.red
        initialsButton.clipsToBounds = true
        setUserImage()
    }
    
    func disableUserInteraction() {
        self.isUserInteractionEnabled = false
    }
    
    @objc func resetUserDetails() {
        self.initialsButton.setBackgroundImage(nil, for: .normal)
        self.initialsButton.setTitle(nil, for: .normal)
    }
    
    func setUserImage() {
        if let userDetails = DataService.instance.userDetails {
            guard initialsButton.backgroundImage(for: .normal) == nil else {
                return
            }
            if let photo = userDetails.photo {
                guard let photoUrl = URL(string: photo) else {
                    setUserInitials()
                    return
                }
                ImageDownloader.getImageFor(url: photoUrl, completion: { (image) in
                    guard let image = image else {
                        self.setUserInitials()
                        return
                    }
                    self.initialsButton.setBackgroundImage(image, for: .normal)
                })
            }
        } else {
            DataService.instance.getUserDetails(completion: {
                self.setUserImage()
            })
        }
    }
    
    func setUserInitials() {
        if let userName = DataService.instance.userDetails?.displayName {
            let words = userName.split(separator: " ")
            let initials = words.map{String($0.first!).uppercased()}
            initialsButton.setTitle(initials.joined(separator: " "), for: .normal)
        }
    }
}
